extend_program

Function extend_program 

pub fn extend_program(
    program_address: &Pubkey,
    payer_address: Option<&Pubkey>,
    additional_bytes: u32,
) -> Instruction
Available on crate feature bincode only.
Returns the instruction required to extend the size of a program’s executable data account.

After SIMD-0431 activation, additional_bytes must be at least MINIMUM_EXTEND_PROGRAM_BYTES unless the account is near the max permitted data length of an account: 10 MiB.